==> TaltOSv0.1.1.zip: TaltOSv0.1.1/TaltOS/TaltOS.h <==
/*
	TaltOS header
	on the Philips Chip LPC2106

	General Public Licence
	By Peter Eordegh
*/


//Clear the tasklist
void TaltOS_clear_tasklist_clear();

//Clear the input buffer
void TaltOS_clear_input_buffer();

//Clear the flash operation buffer
void TaltOS_clear_flash_op_buffer();

//Clear the environement variables of the TalOS
void TaltOS_clear_environement();

//The TaltOS initialization routine
void TaltOS_init();

//The TaltOS main loop
void TaltOS_loop();

//The TaltOS tic routine for the preemtive task change
void TaltOS_tic();

//The input buffer's input function, can be called by the microcontroller
void TaltOS_char_input_write(unsigned char inchar);

//The input buffer's output function, can be called by the tasks to recive data from out of the system
int TaltOS_char_input_read(unsigned char* ret);

//The output buffer's input function, can be called by the tasks to send data out of system
void TaltOS_char_output_write(unsigned char inchar);

//The output buffer's output function, can be called by the microcontroller
int TaltOS_char_output_read(unsigned char* ret);

//Get the component's address by it's ID (Absolute address)
unsigned long* TaltOS_get_component_address(unsigned long id1, unsigned long id2);

//Get the component's n. function's pointer (Absolute address)
unsigned long TaltOS_get_component_function(unsigned long* address, unsigned long index);

//Run all the components' init function (needed after a reset)
void TaltOS_run_components_init();

//Check if a component has arrived into the input buffer
unsigned int TaltOS_component_arrived();

//Checks if the component's ids are garbage (wrong value => error in erase operation)
unsigned int TaltOS_is_garbage_reg(char *test_array);

==> TaltOSv0.1.3.zip: TaltOSv0.1.3/TaltOS/TaltOS.h <==
/*
	TaltOS header
	on the Philips Chip LPC2106

	By Peter Eordegh
*/


//Clear the tasklist
void TaltOS_clear_tasklist_clear();

//Clear the input buffer
void TaltOS_clear_input_buffer();

//Clear the flash operation buffer
void TaltOS_clear_flash_op_buffer();

//Clear the environement variables of the TalOS
void TaltOS_clear_environement();

//The TaltOS initialization routine
void TaltOS_init();

//The TaltOS main loop
void TaltOS_loop();

//The TaltOS tic routine for the preemtive task change
void TaltOS_tic();

//The input buffer's input function, can be called by the microcontroller
void TaltOS_long_input_write(unsigned long inchar);

//The input buffer's output function, can be called by the tasks to recive data from out of the system
unsigned int TaltOS_long_input_read(unsigned long* ret);

//The output buffer's input function, can be called by the tasks to send data out of system
void TaltOS_long_output_write(unsigned long inchar);

//The output buffer's output function, can be called by the microcontroller
unsigned int TaltOS_long_output_read(unsigned long* ret);

//Get the component's address by it's ID (Absolute address)
unsigned long* TaltOS_get_component_address(unsigned long id1, unsigned long id2);

//Get the component's n. function's pointer (Absolute address)
unsigned long TaltOS_get_component_function(unsigned long* address, unsigned long index);

//Searches, runs and ends the next task in the task list (concerning prioroty)
void TaltOS_set_run_end_next_task();

///The Task adding function
unsigned int TaltOS_add_task(unsigned long address, unsigned short priority, unsigned long argument);

//Run and list all the components' init function (needed after a reset)
void TaltOS_run_and_list_components(unsigned long should_do);

//Check if a component has arrived into the input buffer
unsigned int TaltOS_component_arrived();

//Checks if the component's ids are garbage (wrong value => error in erase operation)
unsigned int TaltOS_is_garbage_reg(TaltOS_reg_entity *test_reg);

//Checks if an order arrived to the TaltOS
void TaltOS_check_order();

//Clearing the order arrived to the TaltOS
void TaltOS_end_order();
